
.. log_calls documentation master file, created by
   sphinx-quickstart on Sun Dec 27 19:52:08 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

`log_calls` Documentation (release |release|)
===================================================
Table of Contents
------------------

..  toctree::
    :maxdepth: 1

    intro
    whats_new
    installation
    quickstart
    what_log_calls_can_decorate
    parameters
    decorating_classes
    accessing_method_wrappers
    writing_indent_aware_debug_messages
    using_loggers
    retrieving_changing_defaults
    bulk_external_redecorating
    dynamic_control_of_settings
    indirect_values
    call_history_and_statistics
    call_chains
    further_examples_and_use_cases
    record_history_deco
    appendix_I_parameters_reference
    appendix_II_what_has_been_new

.. Index
.. ------

* :ref:`genindex`

